aboutsummaryrefslogtreecommitdiff
path: root/gitstatus.plugin.sh
diff options
context:
space:
mode:
authorromkatv <roman.perepelitsa@gmail.com>2020-05-11 16:29:08 +0300
committerromkatv <roman.perepelitsa@gmail.com>2020-05-11 16:29:08 +0300
commitd047ed87a1093b27aff3324ba57860c9c42f7b65 (patch)
treefef3bc15a91f96e2f4c836ef34072f758b62e378 /gitstatus.plugin.sh
parentbc85e46f8b8a548379144732a3218bfe686f2f63 (diff)
Squashed 'gitstatus/' changes from 6a4f0fc0..cd5673b4
cd5673b4 increase default gitstatus_start timeout from 5s to 30s git-subtree-dir: gitstatus git-subtree-split: cd5673b4971bf1a6d9aa8d57963e954e619b950e
Diffstat (limited to 'gitstatus.plugin.sh')
-rw-r--r--gitstatus.plugin.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/gitstatus.plugin.sh b/gitstatus.plugin.sh
index 7385defa..75bc2688 100644
--- a/gitstatus.plugin.sh
+++ b/gitstatus.plugin.sh
@@ -8,7 +8,7 @@
# Usage: gitstatus_start [OPTION]...
#
# -t FLOAT Fail the self-check on initialization if not getting a response from
# gitstatusd for this this many seconds. Defaults to 5.
#
# -s INT Report at most this many staged changes; negative value means infinity.
# Defaults to 1.
@@ -37,7 +37,7 @@
# changes for repositories with bash.showDirtyState = false.
function gitstatus_start() {
unset OPTIND
- local opt timeout=5 max_dirty=-1 extra_flags
+ local opt timeout=30 max_dirty=-1 extra_flags
local max_num_staged=1 max_num_unstaged=1 max_num_conflicted=1 max_num_untracked=1
local ignore_status_show_untracked_files
while getopts "t:s:u:c:d:m:eUWD" opt; do
@@ -8,7 +8,7 @@
#
# -t FLOAT Fail the self-check on initialization if not getting a response from
-# gitstatusd for this this many seconds. Defaults to 5.
+# gitstatusd for this this many seconds. Defaults to 30.
#
# -s INT Report at most this many staged changes; negative value means infinity.